@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "code-awareness" "20251117.617"
-  "Code Awareness collaboration package."
+(define-package "code-awareness" "20260212.1934"
+  "Kawa Code collaboration package."
   '((emacs "27.1"))
   :url "https://github.com/CodeAwareness/ca.emacs"
-  :commit "16b700570ea8902830607575f3418f970dffe4c0"
-  :revdesc "16b700570ea8"
+  :commit "ef24e5c4fc7b75fbe1d0c34b11821dd67f2ad40c"
+  :revdesc "ef24e5c4fc7b"
   :keywords '("tools" "convenience" "vc")
   :authors '(("Mark Vasile" . "mark@code-awareness.com"))
   :maintainers '(("Mark Vasile" . "mark@code-awareness.com")))
